@@ -4,12 +4,10 @@ Initialize tiddlyspace as a tiddlyweb plugin.
 
 from tiddlyweb.util import merge_config
 
-from tiddlywebplugins.instancer.util import get_tiddler_locations
 from tiddlywebplugins.utils import remove_handler
 
 from tiddlywebplugins.tiddlyspace.commands import establish_commands
 from tiddlywebplugins.tiddlyspace.config import config as space_config
-from tiddlywebplugins.tiddlyspace.instance import store_contents
 from tiddlywebplugins.tiddlyspace.www import establish_www
 
 
@@ -71,16 +69,11 @@ def init_plugin(config):
     # Without this, config settings from tiddlywebwiki take precedence.
     config['serializers']['text/x-tiddlywiki'] = space_config[
             'serializers']['text/x-tiddlywiki']
-    # This only fixes 'twanager update', instance creation still does not have
-    # the right information, thus requiring a twanager update after instance
-    # creation. Presumably the instance script needs to do something similar.
-    config['instance_tiddlers'] = get_tiddler_locations(store_contents,
-            'tiddlywebplugins.tiddlyspace')
 
     # When tiddlyspace.frontpage_installed is True, don't update
     # the frontpage_public bag, thus not overwriting what's there.
     if config.get('tiddlyspace.frontpage_installed', False):
-        config['instance_tiddlers']['frontpage_public'] = []
+        config['pkgstore.skip_bags'] = ['frontpage_public']
 
     if 'selector' in config:  # system plugin
         # remove friendlywiki
